==> binary-tree-1.0.1.tgz: package/README.md <==
# binary-tree
Data structure in your javascript code, Binary Trees.

[![Build Status](https://travis-ci.com/siddhesh321995/node-dsinjs-binarytree.svg?branch=main)](https://travis-ci.com/siddhesh321995/node-dsinjs-binarytree)
![Node.js CI](https://github.com/siddhesh321995/node-dsinjs-binarytree/workflows/Node.js%20CI/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/siddhesh321995/node-dsinjs-binarytree/badge.svg?branch=main)](https://coveralls.io/github/siddhesh321995/node-dsinjs-binarytree?branch=main)

## Installation:
Using npm
```
npm install @dsinjs/binary-tree --save
```
Or directly on your browser, simply download your file from the following:
- [dsinjs-binarytree.js](dist/dsinjs-binarytree.js) Development version
- [dsinjs-binarytree.min.js](dist/dsinjs-binarytree.min.js) Deployment version
```
<script type="application/javascript" src="dsinjs-binarytree.js"></script>
<script type="application/javascript" src="dsinjs-binarytree.min.js"></script>
```
## Recent features added in the library
- Ajax: XHR wrapper for frontend.
- EventManager: Custom event manager.

## Some sample utility functions
```
const BTreeNode = require('dsinjs-binarytree');
```
```
var node = new BTreeNode({ value: 10 });
var nodel = new BTreeNode({ value: 15, lNode: node });
```

## Complete Documentation
Checkout [DOCUMENTATION.md](DOCUMENTATION.md) for complete documentation or View Documentation online at [https://siddhesh321995.github.io/node-dsinjs-binarytree/](https://siddhesh321995.github.io/node-dsinjs-binarytree/)

## All Features:
- Data type check functions.
- Frontend XHR wrapper.
- EnumGenerator, defaultsGenerator functions.
- 0 Dependancy.

## Help us expand:
Let me know in issues/github page or on email which javascript functions to include in next release.
Check all the [Contributors](Contributors.md) to this library.

==> binary-tree-1.0.3.tgz: package/README.md <==
# @dsinjs/binary-tree
Data structure in your javascript code, Binary Trees.

[![Build Status](https://travis-ci.com/dsinjs/binary-tree.svg?branch=main)](https://travis-ci.com/dsinjs/binary-tree)
![Node.js CI](https://github.com/dsinjs/binary-tree/workflows/Node.js%20CI/badge.svg?branch=main)
[![Coverage Status](https://coveralls.io/repos/github/siddhesh321995/node-dsinjs-binarytree/badge.svg?branch=main)](https://coveralls.io/github/siddhesh321995/node-dsinjs-binarytree?branch=main)

## Installation:
Using npm
```
npm install @dsinjs/binary-tree --save
```
Or directly on your browser, simply download your file from the following:
- [dsinjs-binarytree.js](dist/dsinjs-binarytree.js) Development version
- [dsinjs-binarytree.min.js](dist/dsinjs-binarytree.min.js) Deployment version
```
<script type="application/javascript" src="dsinjs-binarytree.js"></script>
<script type="application/javascript" src="dsinjs-binarytree.min.js"></script>
```
## Recent features added in the library
- Ajax: XHR wrapper for frontend.
- EventManager: Custom event manager.

## Some sample utility functions
```
const BTreeNode = require('@dsinjs/binary-tree');
```
```
var node = new BTreeNode({ value: 10 });
var nodel = new BTreeNode({ value: 15, lNode: node });
```

## Complete Documentation
Checkout [DOCUMENTATION.md](DOCUMENTATION.md) for complete documentation or View Documentation online at [https://github.com/dsinjs/binary-tree/](https://github.com/dsinjs/binary-tree/)

## All Features:
- Data type check functions.
- Frontend XHR wrapper.
- EnumGenerator, defaultsGenerator functions.
- 0 Dependancy.

## Help us expand:
Let me know in issues/github page or on email which javascript functions to include in next release.
Check all the [Contributors](Contributors.md) to this library.
